@@ -119,13 +119,14 @@ def del_ldap_group(groupName):
 
 
 def _insert_jos_xgroups(db, name, description):
-	sql =  "INSERT INTO jos_xgroups ( `cn`, `description`, `published`, `type`, `access`, `public_desc`, `private_desc`, `restrict_msg`, "
-	sql += "`join_policy`, `privacy`, `discussion_email_autosubscribe`, `logo`, `overview_type`, `overview_content`, `plugins`, `created`,"
+	sql =  "INSERT INTO jos_xgroups ( `cn`, `description`, `published`, `type`, `public_desc`, `private_desc`, `restrict_msg`, "
+	sql += "`join_policy`, `discussion_email_autosubscribe`, `logo`, `overview_type`, `overview_content`, `plugins`, `created`,"
 	sql += "`created_by`, `params`) " 
-	sql += "VALUES (" + '%s,'*17 + "%s );" 
+	sql += "VALUES (" + '%s,'*15 + "%s );" 
+	data = (name, description, 0, 1, '', '', '', 1, 0, '', None, None, None, datetime.datetime.now(), None, None)
 
-	data = (name, description, 0, 1, 0, '', '', '',   1, 1, 0, '', None, None, None, datetime.datetime.now(), None, None)
 	gidNumber = db.query_lastrowid(sql, data)
+
 	return gidNumber
 
 
