@@ -115,21 +115,42 @@ def _del_jos_xprofiles(db, uidNumber):
 	db.query_rowcount(sql, data)
 
 
-def _update_jos_xprofiles_pw(db, userid, pwHash):
+def _update_jos_xprofiles_pw(db, userid, password):
+        if password != '*':
+               pw = hubzero.config.passwords.MD5PasswordHash(password)
+        elif '{MD5}' in password:
+                pw = password
+        else:
+                pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
+
 	sql = "UPDATE `jos_xprofiles` SET `userPassword`=%s WHERE `uidNumber`=%s"
-	data = (pwHash, userid)
+	data = (pw, userid)
 	db.query_rowcount(sql, data)
 
 
-def _update_jos_users_pw(db, userid, pwHash):
+def _update_jos_users_pw(db, userid, password):
+        if password != '*':
+               pw = hubzero.config.passwords.MD5PasswordHash(password)
+        elif '{MD5}' in password:
+                pw = password
+        else:
+                pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
+
 	sql = "UPDATE `jos_users` SET `password` = %s WHERE `id`=%s"
-	data = (pwHash, userid)
+	data = (pw, userid)
 	db.query_rowcount(sql, data)
 	
 
-def _update_jos_users_password(db, userid, pwHash):
+def _update_jos_users_password(db, userid, password):
+        if password != '*':
+               pw = hubzero.config.passwords.MD5PasswordHash(password)
+        elif '{MD5}' in password:
+                pw = password
+        else:
+                pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
+
 	sql = "UPDATE `jos_users_password` SET `passhash` = %s WHERE `user_id`=%s"
-	data = (pwHash, userid)
+	data = (pw, userid)
 	db.query_rowcount(sql, data)
 	
 
@@ -137,11 +158,18 @@ def _update_jos_users_password(db, userid, pwHash):
 	
 	
 
-def _update_ldap_user_pw(username, uidNumber, pw):
+def _update_ldap_user_pw(username, uidNumber, password):
 	"""
 	Use raw pw here, we'll hash it
 	"""
 
+        if password != '*':
+               pw = hubzero.config.passwords.MD5PasswordHash(password)
+        elif '{MD5}' in password:
+                pw = password
+        else:
+                pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
+
 	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
 	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
 	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")	
@@ -151,10 +179,7 @@ def _update_ldap_user_pw(username, uidNumber, pw):
 
 	dn = "uid=" + username + ",ou=users," + hubLDAPBaseDN
 	
-	if pw != '*':
-		attrs = [ (ldap.MOD_REPLACE, 'userPassword', hubzero.config.passwords.MD5PasswordHash(pw)) ]
-	else:
-		attrs = [ (ldap.MOD_REPLACE, 'userPassword', "{MD5}*") ]
+	attrs = [ (ldap.MOD_REPLACE, 'userPassword', pw) ]
 
 	l.modify_s(dn, attrs)	
 	
@@ -213,7 +238,7 @@ def _insert_jos_xprofiles(db, hubname, uid, fname, mname, lname, username, email
 	sql += "VALUES (" + '%s,'*37 + "%s );" 
 	
 	data = (uid, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
-	        '/usr/lib/sftp-server', hubzero.config.passwords.MD5PasswordHash(pw), gid, '', '', '', '', '', '', '', 
+	        '/usr/lib/sftp-server', pw, gid, '', '', '', '', '', '', '', 
 	        0, 0, 3, '0000-00-00 00:00:00', 1, '', '', '', '',
 	        '', '', fname, mname, lname, '', 0, 0, '', '', None)
 	db.query_rowcount(sql, data)
